@@ -11,8 +11,8 @@ from tenacity import (
     retry_if_exception_type,
 )
 
-from .tools import Tools
-from .utils import get_logger
+from up42.tools import Tools
+from up42.utils import get_logger
 
 logger = get_logger(__name__)
 
@@ -69,7 +69,7 @@ class Auth(Tools):
 
     def _find_credentials(self) -> None:
         """
-        Sources the project credentials from a provided config file and error handling
+        Sources the project credentials from a provided config file, error handling
         if no credentials are provided in arguments or config file.
         """
         if self.project_id is None or self.project_api_key is None:
@@ -189,7 +189,7 @@ class Auth(Tools):
         data: Union[Dict, List] = {},
         querystring: Dict = {},
         return_text: bool = True,
-    ) -> Union[str, requests.Response]:
+    ) -> Union[str, Dict, requests.Response]:
         """
         Handles retrying the request and automatically gets a new token if the old
         is invalid.
