@@ -5,7 +5,6 @@ from geopandas import GeoDataFrame
 from shapely.geometry import shape
 from shapely.geometry import Point, Polygon
 from geojson import Feature, FeatureCollection
-from requests.exceptions import HTTPError
 from tqdm import tqdm
 
 from up42.auth import Auth
@@ -17,11 +16,17 @@ logger = get_logger(__name__)
 
 supported_sensors = {
     "pleiades": {
-        "blocks": ["oneatlas-pleiades-fullscene", "oneatlas-pleiades-aoiclipped",],
+        "blocks": [
+            "oneatlas-pleiades-fullscene",
+            "oneatlas-pleiades-aoiclipped",
+        ],
         "provider": "oneatlas",
     },
     "spot": {
-        "blocks": ["oneatlas-spot-fullscene", "oneatlas-spot-aoiclipped",],
+        "blocks": [
+            "oneatlas-spot-fullscene",
+            "oneatlas-spot-aoiclipped",
+        ],
         "provider": "oneatlas",
     },
     "sentinel1": {
@@ -41,7 +46,9 @@ supported_sensors = {
     },
     "sentinel3": {"blocks": ["sobloo-sentinel3-full"], "provider": "sobloo-image"},
     "sentinel5p": {
-        "blocks": ["sobloo-sentinel5-preview-full",],
+        "blocks": [
+            "sobloo-sentinel5-preview-full",
+        ],
         "provider": "sobloo-image",
     },
 }
@@ -64,7 +71,13 @@ class Catalog(Tools):
     @staticmethod
     def construct_parameters(
         geometry: Union[
-            Dict, Feature, FeatureCollection, List, GeoDataFrame, Point, Polygon,
+            Dict,
+            Feature,
+            FeatureCollection,
+            List,
+            GeoDataFrame,
+            Point,
+            Polygon,
         ],
         start_date: str = "2020-01-01",
         end_date: str = "2020-01-30",
@@ -112,7 +125,9 @@ class Catalog(Tools):
                 )
             block_filters.extend(supported_sensors[sensor]["blocks"])
 
-        aoi_fc = any_vector_to_fc(vector=geometry,)
+        aoi_fc = any_vector_to_fc(
+            vector=geometry,
+        )
         aoi_geometry = fc_to_query_geometry(
             fc=aoi_fc,
             geometry_operation="intersects",
@@ -247,23 +262,21 @@ class Catalog(Tools):
 
         out_paths: List[str] = []
         for image_id in tqdm(image_ids):
-            out_path = output_directory / f"quicklook_{image_id}.jpg"
-            out_paths.append(str(out_path))
-
-            url = (
-                f"{self.auth._endpoint()}/catalog/{provider}/image/{image_id}/quicklook"
-            )
             try:
+                url = f"{self.auth._endpoint()}/catalog/{provider}/image/{image_id}/quicklook"
+
                 response = self.auth._request(
                     request_type="GET", url=url, return_text=False
                 )
-                response.raise_for_status()
-            except HTTPError as err:
-                raise SystemExit(err)
-
-            with open(out_path, "wb") as dst:
-                for chunk in response:
-                    dst.write(chunk)
+                out_path = output_directory / f"quicklook_{image_id}.jpg"
+                out_paths.append(str(out_path))
+                with open(out_path, "wb") as dst:
+                    for chunk in response:
+                        dst.write(chunk)
+            except ValueError:
+                logger.warning(
+                    f"Image with id {image_id} does not have quicklook available. Skipping ..."
+                )
 
         self.quicklooks = out_paths  # pylint: disable=attribute-defined-outside-init
         return out_paths
